==> huaweicloudsdkelb-3.0.64-py2.py3-none-any.whl: huaweicloudsdkelb/v3/model/create_ip_group_request_body.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateIpGroupRequestBody:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'ipgroup': 'CreateIpGroupOption'
    }

    attribute_map = {
        'ipgroup': 'ipgroup'
    }

    def __init__(self, ipgroup=None):
        """CreateIpGroupRequestBody - a model defined in huaweicloud sdk"""
        
        

        self._ipgroup = None
        self.discriminator = None

        self.ipgroup = ipgroup

    @property
    def ipgroup(self):
        """Gets the ipgroup of this CreateIpGroupRequestBody.


        :return: The ipgroup of this CreateIpGroupRequestBody.
        :rtype: CreateIpGroupOption
        """
        return self._ipgroup

    @ipgroup.setter
    def ipgroup(self, ipgroup):
        """Sets the ipgroup of this CreateIpGroupRequestBody.


        :param ipgroup: The ipgroup of this CreateIpGroupRequestBody.
        :type: CreateIpGroupOption
        """
        self._ipgroup = ipgroup

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateIpGroupRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkelb-3.0.107-py2.py3-none-any.whl: huaweicloudsdkelb/v3/model/create_ip_group_request_body.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateIpGroupRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'ipgroup': 'CreateIpGroupOption'
    }

    attribute_map = {
        'ipgroup': 'ipgroup'
    }

    def __init__(self, ipgroup=None):
        """CreateIpGroupRequestBody

        The model defined in huaweicloud sdk

        :param ipgroup: 
        :type ipgroup: :class:`huaweicloudsdkelb.v3.CreateIpGroupOption`
        """
        
        

        self._ipgroup = None
        self.discriminator = None

        self.ipgroup = ipgroup

    @property
    def ipgroup(self):
        """Gets the ipgroup of this CreateIpGroupRequestBody.


        :return: The ipgroup of this CreateIpGroupRequestBody.
        :rtype: :class:`huaweicloudsdkelb.v3.CreateIpGroupOption`
        """
        return self._ipgroup

    @ipgroup.setter
    def ipgroup(self, ipgroup):
        """Sets the ipgroup of this CreateIpGroupRequestBody.


        :param ipgroup: The ipgroup of this CreateIpGroupRequestBody.
        :type ipgroup: :class:`huaweicloudsdkelb.v3.CreateIpGroupOption`
        """
        self._ipgroup = ipgroup

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateIpGroupRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
